@@ -27,10 +27,16 @@ from threading import Event, Lock, Semaphore, Thread
 from typing import cast, Any, ContextManager, Literal
 
 from argtools import argcount
-from asynctools import ensure_coroutine
+from asynctools import ensure_coroutine, run_async
 from decotools import optional
 
 
+if "__del__" not in ThreadPoolExecutor.__dict__:
+    setattr(ThreadPoolExecutor, "__del__", lambda self, /: self.shutdown(wait=False, cancel_futures=True))
+if "__del__" not in TaskGroup.__dict__:
+    setattr(ThreadPoolExecutor, "__del__", lambda self, /: run_async(self.__aexit__(None, None, None)))
+
+
 def thread_batch[T, V](
     work: Callable[[T], V] | Callable[[T, Callable], V], 
     tasks: Iterable[T], 
